@@ -45,7 +45,6 @@ mod system;
 mod unique;
 mod workers;
 
-pub use delay::*;
 pub use error::*;
 pub use forwarder::*;
 pub use lease::*;
@@ -63,6 +62,7 @@ pub use workers::*;
 
 pub mod channel;
 pub mod pipe;
+pub mod pipe2;
 pub mod stream;
 
 pub use ockam_core::{
