@@ -1,5 +1,5 @@
+use ockam_core::compat::rand::{thread_rng, Rng};
 use ockam_core::compat::string::String;
-use rand::{thread_rng, Rng};
 
 /// A simple generator for unique, human-readable identifiers suitable
 /// for use in distributed systems.
